def getargs():
    from argparse import ArgumentParser
    '''
    Return arguments
    '''
    parser = ArgumentParser(description='Answer yes or no to a question.')
    parser.add_argument("question", type=str, help="A question to ask.")
    return parser.parse_args()


def cats():
    from os import name
    from os import system
    '''
    CLEAR ALL THE SCREENS!
    '''
    if name == 'nt':
        system('cls')
    else:
        system('clear')


def main():
    from .ask import ask

    args = getargs()
    cats()
    question = args.question

    if ask(question):
        print("\nYou answered yes.\n")
    else:
        print("\nYou answered no.\n")


if __name__ == '__main__':
    main()



import readline
from sys import stdout
from re import match

RED = "\033[1;31m"
CYAN = "\033[1;36m"
RESET = "\033[0;0m"


def ask(question):
    '''
    Infinite loop to get yes or no answer or quit the script.
    '''
    while True:
        ans = input("\n" + question)
        al = ans.lower()
        if match('^y(es)?$', al):
            return True
        elif match('^n(o)?$', al):
            return False
        elif match('^q(uit)?$', al):
            stdout.write(CYAN)
            print("\nGoodbye.\n")
            stdout.write(RESET)
            quit()
        else:
            stdout.write(RED)
            print("%s is invalid. Enter (y)es, (n)o or (q)uit." % ans)
            stdout.write(RESET)
